@@ -4,7 +4,7 @@ dist.SM<-function(x)
 	if(is.data.frame(x)) x<-as.matrix(x)
 	nr=nrow(x)
 	t<-.C("fng3",as.double(x),as.integer(nrow(x)),as.integer(ncol(x)),wynik=double(nrow(x)*nrow(x)),PACKAGE="clusterSim")$wynik
-	wynik<-matrix(nrow=nr,ncol=nr,dimnames=x$names)
+	wynik<-matrix(nrow=nr,ncol=nr,dimnames=names(x))
 	for (i in 1:nr)
 	for (j in 1:nr)
 	{
